@@ -1,5 +1,5 @@
 __title__ = "Django Consistency Model"
-__version__ = "0.1"
+__version__ = "0.1.1"
 __author__ = "Alex Liabakh"
 
 from .tools import (
@@ -12,4 +12,5 @@ from .tools import (
     gen_validators_by_func,
     gen_validators,
     gen_consistency_errors,
+    monitoring_iteration,
 )
